==> 0.0.7.tar.gz: android/src/main/java/com/dh/fluttergooglefit/FlutterGooglefitPlugin.java <==
package com.dh.fluttergooglefit;

import android.app.Activity;
import android.content.Intent;
import android.content.pm.ActivityInfo;
import android.support.annotation.NonNull;
import android.util.Log;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;
import io.flutter.plugin.common.PluginRegistry;

import com.google.android.gms.auth.api.signin.GoogleSignIn;
import com.google.android.gms.fitness.Fitness;
import com.google.android.gms.fitness.FitnessOptions;
import com.google.android.gms.fitness.data.DataPoint;
import com.google.android.gms.fitness.data.DataSet;
import com.google.android.gms.fitness.data.DataType;
import com.google.android.gms.fitness.data.Field;
import com.google.android.gms.fitness.request.DataReadRequest;
import com.google.android.gms.fitness.result.DataReadResponse;
import com.google.android.gms.tasks.OnCanceledListener;
import com.google.android.gms.tasks.OnCompleteListener;
import com.google.android.gms.tasks.OnFailureListener;
import com.google.android.gms.tasks.OnSuccessListener;
import com.google.android.gms.tasks.Task;

import java.util.Calendar;
import java.util.concurrent.TimeUnit;

public class FlutterGooglefitPlugin implements MethodCallHandler, PluginRegistry.ActivityResultListener {
  private Registrar registrar;
  private Result result;

  // 필요한 권한들 정의
  FitnessOptions fitnessOptions =
          FitnessOptions.builder()
                  .addDataType(DataType.TYPE_STEP_COUNT_CUMULATIVE, FitnessOptions.ACCESS_READ)
                  .addDataType(DataType.TYPE_STEP_COUNT_DELTA, FitnessOptions.ACCESS_READ)
                  .build();

  public static void registerWith(Registrar registrar) {
    final MethodChannel channel = new MethodChannel(registrar.messenger(), "com.dh/flutter_googlefit");
    FlutterGooglefitPlugin googlefitPlugin = new FlutterGooglefitPlugin(registrar);
    channel.setMethodCallHandler(googlefitPlugin);
    registrar.addActivityResultListener(googlefitPlugin);
  }

  private FlutterGooglefitPlugin(Registrar registrar) {
    this.registrar = registrar;
  }

  @Override
  public void onMethodCall(MethodCall call, Result result) {

    switch (call.method) {
      case "reqPermissionGoogleFit":
        Log.e("tttttttttttttttt" , "tttttttttttttttttttttttttttttttttttttttttttttttttttttttttt onMethodCall: ");
        ReqPermissionGoogleFit();
        this.result = result;
        break;
      default:
        result.notImplemented();
        break;
    }
  }

  @Override
  public boolean onActivityResult(int i, int i1, Intent intent) {

    Log.e("tttttttttttttttt" , "tttttttttttttttttttttttttttttttttttttttttttttttttttttttttt : " + i  + " aaaaaaaa : " + i1 );
    if (i == 0 && i1 > 0) {
    }
    result.success("");
    return true;
  }


  // 피트 권한 확인.
  public boolean CheckPermissionFit()
  {
    return GoogleSignIn.hasPermissions(GoogleSignIn.getLastSignedInAccount(registrar.activity()), fitnessOptions);
  }

  // 피트 권한 요청.
  public void ReqPermissionGoogleFit()
  {
    if(!CheckPermissionFit()) {
      GoogleSignIn.requestPermissions(registrar.activity(), 375678, GoogleSignIn.getLastSignedInAccount(registrar.activity()), fitnessOptions);
    }
    else
    {
      result.success("");
    }
  }

  public void GetTotalStep()
  {
    if(CheckPermissionFit()){
      AddListenerFIt();
    }
  }

  public void AddListenerFIt()
  {
    Fitness.getRecordingClient(registrar.activity(),
            GoogleSignIn.getLastSignedInAccount(registrar.activity()))
            .subscribe(DataType.TYPE_STEP_COUNT_CUMULATIVE)
            .addOnFailureListener(new OnFailureListener() {
              @Override
              public void onFailure(@NonNull Exception e) {
                Log.i("healthcoin", "Failure listener");
              }
            })
            .addOnCompleteListener(new OnCompleteListener<Void>() {
              @Override
              public void onComplete(@NonNull Task<Void> task) {
                if (task.isSuccessful()) {
                  readTotalStepData();
                } else {
                  Log.w("healcoin", "There was a problem subscribing.", task.getException());
                }
              }
            });
  }

  public void readTotalStepData() {
    final Calendar cal = Calendar.getInstance();
    cal.add(Calendar.DATE, -1);
    // 시작 시간
    cal.set(cal.get(Calendar.YEAR), cal.get(Calendar.MONTH),
            cal.get(Calendar.DAY_OF_MONTH), 0, 0, 0);
    long startTime = cal.getTimeInMillis();

    // 종료 시간
    cal.set(cal.get(Calendar.YEAR), cal.get(Calendar.MONTH),
            cal.get(Calendar.DAY_OF_MONTH), 23, 59, 50);
    long endTime = cal.getTimeInMillis();

    Fitness.getHistoryClient(registrar.activity(),
            GoogleSignIn.getLastSignedInAccount(registrar.activity()))
            .readData(new DataReadRequest.Builder()
                    .read(DataType.AGGREGATE_STEP_COUNT_DELTA ) // Raw 걸음 수
                    .setTimeRange(startTime, endTime, TimeUnit.MILLISECONDS)
                    .build())
            .addOnFailureListener(new OnFailureListener() {
              @Override
              public void onFailure(@NonNull Exception e) {
                Log.i("healthcoin", "Failure readTotalStepData");
              }
            })
            .addOnCanceledListener(new OnCanceledListener() {
              @Override
              public void onCanceled() {
                Log.i("healthcoin", "Cancel readTotalStepData");
              }
            })
            .addOnSuccessListener(new OnSuccessListener<DataReadResponse>() {
              @Override
              public void onSuccess(DataReadResponse response) {
                DataSet dataSet = response.getDataSet(DataType.AGGREGATE_STEP_COUNT_DELTA );
                int temp = 0;
                for (DataPoint dp : dataSet.getDataPoints()) {
                  for (Field field : dp.getDataType().getFields()) {
                    temp = temp + Integer.parseInt( dp.getValue(field).toString() );
                  }
                }
                Log.i("healthcoin", "\tTotal Step : " + temp);

              }
            });
  }
}

==> 0.0.18.tar.gz: android/src/main/java/com/dh/fluttergooglefit/FlutterGooglefitPlugin.java <==
package com.dh.fluttergooglefit;

import android.app.Activity;
import android.content.Intent;
import android.content.pm.ActivityInfo;
import android.support.annotation.NonNull;
import android.util.Log;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;
import io.flutter.plugin.common.PluginRegistry;

import com.google.android.gms.auth.api.signin.GoogleSignIn;
import com.google.android.gms.fitness.Fitness;
import com.google.android.gms.fitness.FitnessOptions;
import com.google.android.gms.fitness.data.DataPoint;
import com.google.android.gms.fitness.data.DataSet;
import com.google.android.gms.fitness.data.DataType;
import com.google.android.gms.fitness.data.Field;
import com.google.android.gms.fitness.request.DataReadRequest;
import com.google.android.gms.fitness.result.DataReadResponse;
import com.google.android.gms.tasks.OnCanceledListener;
import com.google.android.gms.tasks.OnCompleteListener;
import com.google.android.gms.tasks.OnFailureListener;
import com.google.android.gms.tasks.OnSuccessListener;
import com.google.android.gms.tasks.Task;

import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.text.ParseException;
import java.util.Calendar;
import java.util.Date;
import java.util.HashMap;
import java.util.concurrent.TimeUnit;

public class FlutterGooglefitPlugin implements MethodCallHandler, PluginRegistry.ActivityResultListener {
  private Registrar registrar;
  private Result mResult;

  private static final int GOOGLE_FIT_PERMISSIONS_REQUEST_CODE = 375678;

  // 필요한 권한들 정의
  FitnessOptions fitnessOptions =
          FitnessOptions.builder()
                  .addDataType(DataType.TYPE_STEP_COUNT_CUMULATIVE, FitnessOptions.ACCESS_READ)
                  .addDataType(DataType.TYPE_STEP_COUNT_DELTA, FitnessOptions.ACCESS_READ)
                  .build();

  public static void registerWith(Registrar registrar) {
    final MethodChannel channel = new MethodChannel(registrar.messenger(), "com.dh/flutter_googlefit");
    FlutterGooglefitPlugin googlefitPlugin = new FlutterGooglefitPlugin(registrar);
    channel.setMethodCallHandler(googlefitPlugin);
    registrar.addActivityResultListener(googlefitPlugin);
  }

  private FlutterGooglefitPlugin(Registrar registrar) {
    this.registrar = registrar;
  }

  @Override
  public void onMethodCall(MethodCall call, Result result) {
    this.mResult = result;
    switch (call.method) {
      case "reqPermissionGoogleFit":
        ReqPermissionGoogleFit();
        break;
      case "reqTotalStepData":
        readTotalStepData((String)call.arguments);
        break;
      default:
        result.notImplemented();
        break;
    }
  }

  @Override
  public boolean onActivityResult(int requestCode, int reslutCode, Intent intent) {

    if( requestCode == GOOGLE_FIT_PERMISSIONS_REQUEST_CODE )
    {
      if( reslutCode == Activity.RESULT_OK)
      {
        // 성공. 리스너 등록.
        AddListenerFIt();
      }
      else
      {
        // 실패.
      }
      mResult.success("");
    }

    return false;
  }


  // 피트 권한 확인.
  public boolean CheckPermissionFit()
  {
    return GoogleSignIn.hasPermissions(GoogleSignIn.getLastSignedInAccount(registrar.activity()), fitnessOptions);
  }

  // 피트 권한 요청.
  public void ReqPermissionGoogleFit()
  {
    if(!CheckPermissionFit()) {
      GoogleSignIn.requestPermissions(registrar.activity(), GOOGLE_FIT_PERMISSIONS_REQUEST_CODE, GoogleSignIn.getLastSignedInAccount(registrar.activity()), fitnessOptions);
    }
    else
    {
      mResult.success("");
    }
  }

  public void AddListenerFIt()
  {
    Fitness.getRecordingClient(registrar.activity(),
            GoogleSignIn.getLastSignedInAccount(registrar.activity()))
            .subscribe(DataType.TYPE_STEP_COUNT_CUMULATIVE)
            .addOnCanceledListener(new OnCanceledListener() {
              @Override
              public void onCanceled() {
                mResult.error("ReqPermissionGoogleFit", "onCanceled", false);
              }
            })
            .addOnFailureListener(new OnFailureListener() {
              @Override
              public void onFailure(@NonNull Exception e) {
                mResult.error("ReqPermissionGoogleFit", e.toString(), false);
              }
            })
            .addOnCompleteListener(new OnCompleteListener<Void>() {
              @Override
              public void onComplete(@NonNull Task<Void> task) {
                if (task.isSuccessful()) {
                  //readTotalStepData();
                } else {

                }

                mResult.success("");
              }
            });
  }

  public void readTotalStepData(String targetDate) {

    if( CheckPermissionFit() == false )
    {
      mResult.error("readTotalStepData", "NeedPermission", null );
      return;
    }

    SimpleDateFormat formatter = new SimpleDateFormat("yyyyMMdd");
    Date date;
    try{
      date =formatter.parse(targetDate);
    }catch (ParseException e )
    {
      mResult.error("readTotalStepData", "formatter.parse", e );
      return;
    }

    final Calendar cal = Calendar.getInstance();
    cal.setTime(date);
    // 시작 시간
    cal.set(cal.get(Calendar.YEAR), cal.get(Calendar.MONTH),
            cal.get(Calendar.DAY_OF_MONTH), 0, 0, 0);
    long startTime = cal.getTimeInMillis();

    // 종료 시간
    cal.set(cal.get(Calendar.YEAR), cal.get(Calendar.MONTH),
            cal.get(Calendar.DAY_OF_MONTH), 23, 59, 50);
    long endTime = cal.getTimeInMillis();

    Fitness.getHistoryClient(registrar.activity(),
            GoogleSignIn.getLastSignedInAccount(registrar.activity()))
            .readData(new DataReadRequest.Builder()
                    .read(DataType.AGGREGATE_STEP_COUNT_DELTA ) // Raw 걸음 수
                    .setTimeRange(startTime, endTime, TimeUnit.MILLISECONDS)
                    .build())
            .addOnFailureListener(new OnFailureListener() {
              @Override
              public void onFailure(@NonNull Exception e) {
                mResult.error("readTotalStepData", "FailureListener", null);
              }
            })
            .addOnCanceledListener(new OnCanceledListener() {
              @Override
              public void onCanceled() {
                mResult.error("readTotalStepData", "CanceledListener", null);
              }
            })
            .addOnSuccessListener(new OnSuccessListener<DataReadResponse>() {
              @Override
              public void onSuccess(DataReadResponse response) {
                DataSet dataSet = response.getDataSet(DataType.AGGREGATE_STEP_COUNT_DELTA );
                int temp = 0;
                for (DataPoint dp : dataSet.getDataPoints()) {
                  for (Field field : dp.getDataType().getFields()) {
                    temp = temp + Integer.parseInt( dp.getValue(field).toString() );
                  }
                }
                final Integer count = temp;
                mResult.success( count );
              }
            });
  }
}
